@@ -19,24 +19,29 @@ def set_dynamic_settings(s):
     Mezzanine's settings module.
     """
 
-    s["TEMPLATE_DEBUG"] = s["DEBUG"]
+    # Moves an existing list setting value to a different position.
+    move = lambda n, k, i: s[n].insert(i, s[n].pop(s[n].index(k)))
+    # Add a value to a list setting if not in the list.
+    append = lambda n, k: s[n].append(k) if k not in s[n] else None
+
+    s["TEMPLATE_DEBUG"] = s.get("TEMPLATE_DEBUG", s.get("DEBUG", False))
     add_to_builtins("mezzanine.template.loader_tags")
     # Define some settings based on management command being run.
     management_command = sys.argv[1] if len(sys.argv) > 1 else ""
-    # Some kind of testing is running via test or testserver
+    # Some kind of testing is running via test or testserver.
     s["TESTING"] = management_command.startswith("test")
     # Some kind of development server is running via runserver or
     # runserver_plus
     s["DEV_SERVER"] = management_command.startswith("runserver")
-    # Change INSTALLED_APPS to a list for easier manipulation.
+    # Change INSTALLED_APPS and MIDDLEWARE_CLASSES to lists for
+    # easier manipulation.
     s["INSTALLED_APPS"] = list(s["INSTALLED_APPS"])
+    s["MIDDLEWARE_CLASSES"] = list(s["MIDDLEWARE_CLASSES"])
 
     # Set up cookie messaging if none specified for Django >= 1.3
     if VERSION >= (1, 3, 0):
         msg_mw = "django.contrib.messages.middleware.MessageMiddleware"
-        if msg_mw not in s["MIDDLEWARE_CLASSES"]:
-            s["MIDDLEWARE_CLASSES"] = tuple(s["MIDDLEWARE_CLASSES"])
-            s["MIDDLEWARE_CLASSES"] += (msg_mw,)
+        append("MIDDLEWARE_CLASSES", msg_mw)
         if not s.get("MESSAGE_STORAGE"):
             storage = "django.contrib.messages.storage.cookie.CookieStorage"
             s["MESSAGE_STORAGE"] = storage
@@ -56,34 +61,36 @@ def set_dynamic_settings(s):
                     pass
                 else:
                     s["INSTALLED_APPS"].append(app)
-
     if "debug_toolbar" in s["INSTALLED_APPS"]:
         debug_mw = "debug_toolbar.middleware.DebugToolbarMiddleware"
-        if debug_mw not in s["MIDDLEWARE_CLASSES"]:
-            s["MIDDLEWARE_CLASSES"] = tuple(s["MIDDLEWARE_CLASSES"])
-            s["MIDDLEWARE_CLASSES"] += (debug_mw,)
+        append("MIDDLEWARE_CLASSES", debug_mw)
+
+    # Set up filebrowser paths.
     if s.get("PACKAGE_NAME_FILEBROWSER") in s["INSTALLED_APPS"]:
         s["FILEBROWSER_URL_FILEBROWSER_MEDIA"] = "/filebrowser/media/"
         fb_path = path_for_import(s["PACKAGE_NAME_FILEBROWSER"])
         fb_media_path = os.path.join(fb_path, "media", "filebrowser")
         s["FILEBROWSER_PATH_FILEBROWSER_MEDIA"] = fb_media_path
+
+    # Ensure Grappelli is after Mezzanine in app order so that
+    # admin templates are loaded in the correct order.
     grappelli_name = s.get("PACKAGE_NAME_GRAPPELLI")
-    s["GRAPPELLI_INSTALLED"] = grappelli_name in s["INSTALLED_APPS"]
-    if s["GRAPPELLI_INSTALLED"]:
-        # Ensure Grappelli is after Mezzanine in app order so that
-        # admin templates are loaded in the correct order.
-        s["INSTALLED_APPS"].remove(grappelli_name)
-        s["INSTALLED_APPS"].append(grappelli_name)
+    try:
+        move("INSTALLED_APPS", grappelli_name, len(s["INSTALLED_APPS"]))
+    except ValueError:
+        s["GRAPPELLI_INSTALLED"] = False
+    else:
+        s["GRAPPELLI_INSTALLED"] = True
         s.setdefault("GRAPPELLI_ADMIN_HEADLINE", "Mezzanine")
         s.setdefault("GRAPPELLI_ADMIN_TITLE", "Mezzanine")
-        grappelli_path = path_for_import(s["PACKAGE_NAME_GRAPPELLI"])
+        grappelli_path = path_for_import(grappelli_name)
         s["GRAPPELLI_MEDIA_PATH"] = os.path.join(grappelli_path, "media")
         # Adopted from django.core.management.commands.runserver
         # Easiest way so far to actually get all the media for
         # Grappelli working with the dev server is to hard-code the
         # host:port to ADMIN_MEDIA_PREFIX, so here we check for a
         # custom host:port before doing this.
-        if len(sys.argv) >= 2 and sys.argv[1] == "runserver":
+        if s["DEV_SERVER"]:
             addrport = ""
             if len(sys.argv) > 2:
                 addrport = sys.argv[2]
@@ -98,23 +105,23 @@ def set_dynamic_settings(s):
                 addr = "127.0.0.1"
             parts = (addr, port, s["ADMIN_MEDIA_PREFIX"])
             s["ADMIN_MEDIA_PREFIX"] = "http://%s:%s%s" % parts
+
     # Ensure admin is last in the app order so that admin templates
     # are loaded in the correct order.
-    if "django.contrib.admin" in s["INSTALLED_APPS"]:
-        s["INSTALLED_APPS"].remove("django.contrib.admin")
-        s["INSTALLED_APPS"].append("django.contrib.admin")
+    move("INSTALLED_APPS", "django.contrib.admin", len(s["INSTALLED_APPS"]))
 
     # Add missing apps if existing apps depend on them.
-    if ("mezzanine.blog" in s["INSTALLED_APPS"] and
-        "mezzanine.generic" not in s["INSTALLED_APPS"]):
-        s["INSTALLED_APPS"].append("mezzanine.generic")
+    if "mezzanine.blog" in s["INSTALLED_APPS"]:
+        append("INSTALLED_APPS", "mezzanine.generic")
     if "mezzanine.generic" in s["INSTALLED_APPS"]:
         s["COMMENTS_APP"] = "mezzanine.generic"
-        if "django.contrib.comments" not in s["INSTALLED_APPS"]:
-            s["INSTALLED_APPS"].append("django.contrib.comments")
+        append("INSTALLED_APPS", "django.contrib.comments")
 
-    # Change INSTALLED_APPS back to a tuple.
-    s["INSTALLED_APPS"] = tuple(s["INSTALLED_APPS"])
+    # Ensure mezzanine.boot is first.
+    try:
+        move("INSTALLED_APPS", "mezzanine.boot", 0)
+    except ValueError:
+        pass
 
     # Caching.
     if not (s.get("CACHE_BACKEND") or s.get("CACHES")):
@@ -138,8 +145,8 @@ def set_dynamic_settings(s):
         if shortname == "sqlite3" and os.sep not in db["NAME"]:
             # If the Sqlite DB name doesn't contain a path, assume
             # it's in the project directory and add the path to it.
-            s["DATABASES"][key]["NAME"] = os.path.join(
-                                     s.get("PROJECT_ROOT", ""), db["NAME"])
+            db_path = os.path.join(s.get("PROJECT_ROOT", ""), db["NAME"])
+            s["DATABASES"][key]["NAME"] = db_path
         elif shortname == "mysql":
             # Required MySQL collation for tests.
             s["DATABASES"][key]["TEST_COLLATION"] = "utf8_general_ci"
@@ -159,11 +166,16 @@ def set_dynamic_settings(s):
     # Remaining code is for Django 1.1 support.
     if VERSION >= (1, 2, 0):
         return
+
     # Add the dummy csrf_token template tag to builtins and remove
     # Django's CsrfViewMiddleware.
     add_to_builtins("mezzanine.core.templatetags.dummy_csrf")
-    s["MIDDLEWARE_CLASSES"] = [mw for mw in s["MIDDLEWARE_CLASSES"] if
-                        mw != "django.middleware.csrf.CsrfViewMiddleware"]
+    csrf_mw = "django.middleware.csrf.CsrfViewMiddleware"
+    try:
+        s["MIDDLEWARE_CLASSES"].remove(csrf_mw)
+    except ValueError:
+        pass
+
     # Use the single DB settings.
     old_db_settings_mapping = {
         "ENGINE": "DATABASE_ENGINE",
